@@ -42,7 +42,7 @@ class SimulationDataAnalyzer:
         print(Fore.WHITE +  "Simulation Data Analysis Tool Load, Analyze, and Visualize ")
         print(Fore.WHITE +  "CSV Simulation Data Statistical Analysis, Signal Processing, Plotting")
         print(Fore.MAGENTA + "─" * 70)
-        print(Fore.LIGHTBLACK_EX +  " © M.GUENI - 10-05-2025 - v1.0.4")
+        print(Fore.LIGHTBLACK_EX +  " © M.GUENI - 10-05-2025 - v3.0.1")
         # Bottom border
         print(Fore.MAGENTA + "=" * 70)
         print(Style.RESET_ALL)  # Reset colors
@@ -677,6 +677,38 @@ def is_simple_operation(command):
     return False
 
 def main():
+    import sys
+    
+    # Version compatibility check
+    python_version = sys.version_info
+    if python_version < (3, 10, 8):
+        print(f"✗ Python 3.10.8 or higher required. Current version: {python_version.major}.{python_version.minor}.{python_version.micro}")
+        sys.exit(1)
+    
+    # Check critical dependencies
+    try:
+        import numpy as np
+        import pandas as pd
+        import matplotlib.pyplot as plt
+        import pyfiglet
+        from colorama import Fore, Style, init
+        
+        # Verify versions (optional but helpful)
+        numpy_version = tuple(map(int, np.__version__.split('.')[:3]))
+        pandas_version = tuple(map(int, pd.__version__.split('.')[:3]))
+        
+        if numpy_version < (1, 22, 4):
+            print(f"✗ NumPy 1.22.4 or higher required. Current version: {np.__version__}")
+            sys.exit(1)
+            
+        if pandas_version < (2, 2, 2):
+            print(f"✗ pandas 2.2.2 or higher required. Current version: {pd.__version__}")
+            sys.exit(1)
+            
+    except ImportError as e:
+        print(f"✗ Missing required dependency: {e}")
+        print("Please install required packages: pip install numpy>=1.22.4 pandas>=2.2.2 matplotlib>=3.6.2 pyfiglet>=0.8.post1 rich>=14.0.0 colorama>=0.4.6")
+        sys.exit(1)
     
     analyzer = SimulationDataAnalyzer()
     analyzer.display_banner()
